


# TeamTailor Connector

## About TeamTailor:

Teamtailor is the applicant tracking system made for all types of companies. With modern features optimized for you and your candidates, you will get everything you need to recruit successfully.

## Connector features

-   **Pull_Jobs:** Retrieves a list of job IDs from the TeamTailor API, retrieves the corresponding job information and location information for each ID, and sends the formatted data to an HrFlow board.
-   **Push_Profiles:** Retrieves candidate data from an HrFlow source, formats the data as a JSON object, and posts it to the TeamTailor API to create new candidates.

## Requirements:

To use the connector, you will need the following:

-   A TeamTailor API token and API version, which can be obtained by creating an API key in your TeamTailor account.
-   An HrFlow board and source, which can be created at [https://hrflow.ai/](https://hrflow.ai/).

## Useful links:

📄Visit [Teamtailor](https://www.teamtailor.com/) to learn more.

💻 [Connector code]([https://github.com/Sprenger07/hrflow-connectors/tree/feature/update-connector-workable/src/hrflow_connectors/connectors/workable](https://github.com/Sprenger07/hrflow-connectors/tree/feature/update-connector-workable/src/hrflow_connectors/connectors/workable)) on our Github.
